@@ -2,8 +2,8 @@
 from __future__ import print_function
 from ptrace import PtraceError
 from ptrace.debugger import (PtraceDebugger, Application,
-    ProcessExit, NewProcessEvent, ProcessSignal,
-    ProcessExecution, ProcessError)
+                             ProcessExit, NewProcessEvent, ProcessSignal,
+                             ProcessExecution, ProcessError)
 from optparse import OptionParser
 from os import getpid
 from sys import stdout, stderr, exit
@@ -13,7 +13,7 @@ from ptrace.error import PTRACE_ERRORS, writeError
 from ptrace.binding import HAS_PTRACE_SINGLESTEP
 from ptrace.disasm import HAS_DISASSEMBLER
 from ptrace.ctypes_tools import (truncateWord,
-    formatWordHex, formatAddress, formatAddressRange, word2bytes)
+                                 formatWordHex, formatAddress, formatAddressRange, word2bytes)
 from ptrace.process_tools import dumpProcessInfo
 from ptrace.tools import inverseDict
 from ptrace.func_call import FunctionCallOptions
@@ -38,14 +38,14 @@ import re
 if stdout.isatty():
     try:
         # Use readline for better raw_input()
-        import readline
+        import readline   # noqa
     except ImportError:
         pass
 
 # Match a register name: $eax, $gp0, $orig_eax
 REGISTER_REGEX = re.compile(r"\$[a-z]+[a-z0-9_]+")
 
-#BYTES_REGEX = re.compile(r"""(?:'([^'\\]*)'|"([^"\\]*)")""")
+# BYTES_REGEX = re.compile(r"""(?:'([^'\\]*)'|"([^"\\]*)")""")
 
 SIGNALS = inverseDict(SIGNAMES)   # name -> signum
 
@@ -62,9 +62,10 @@ COMMANDS = (
 
     # current process info
     ("regs", "display registers"),
-    ("where", "display true code content (show breakpoints effects on code). eg. 'where $eip', 'where $eip $eip+20'"),
+    ("where", "display true code content (show breakpoints effects on code). e.g. 'where $eip', 'where $eip $eip+20'"),
     ("print", "display a value (print <value>)"),
     ("hexdump", "dump memory as specified address or address range (hexdump <address> or hexdump <start> <stop>)"),
+    ("gcore", "generate core file of the process"),
     ("where2", "display original code content (don't show effects of breakpoint on code)"),
     ("stack", "display stack content"),
     ("backtrace", "dump the backtrace"),
@@ -77,11 +78,11 @@ COMMANDS = (
     ("delete", "delete a breakpoint (delete <address>)"),
 
     # processes
-    ("attach", 'attach a new process (eg. "attach 2390")'),
+    ("attach", 'attach a new process (e.g. "attach 2390")'),
     ("proclist", "list of traced processes"),
     ("switch", "switch active process (switch or switch <pid>)"),
 
-    ("follow", r'''follow a term (eg. "follow '\x12\x14\x27\x13'")'''),
+    ("follow", r'''follow a term (e.g. "follow '\x12\x14\x27\x13'")'''),
     ("showfollow", 'show all "followed" terms'),
     ("resetfollow", 'reset all "followed" terms'),
     ("xray", 'show addresses of (and possible pointers to) "followed" terms'),
@@ -92,6 +93,7 @@ COMMANDS = (
     ("help", "display this help"),
 )
 
+
 def formatAscii(data):
     def asciiChar(byte):
         if 32 <= byte <= 126:
@@ -103,6 +105,7 @@ def formatAscii(data):
     else:
         return u''.join(asciiChar(ord(byte)) for byte in data)
 
+
 def formatHexa(data):
     if RUNNING_PYTHON3:
         return u' '.join(u"%02x" % byte for byte in data)
@@ -111,6 +114,8 @@ def formatHexa(data):
 
 # finds possible pointer values in process memory space,
 # pointing to address
+
+
 def getPointers(process, address):
     address = word2bytes(address)
     procmaps = readProcessMappings(process)
@@ -118,7 +123,9 @@ def getPointers(process, address):
         for found in pm.search(address):
             yield found
 
+
 class Gdb(Application):
+
     def __init__(self):
         Application.__init__(self)
 
@@ -146,7 +153,8 @@ class Gdb(Application):
         self._setupLog(stdout)
 
     def parseOptions(self):
-        parser = OptionParser(usage="%prog [options] -- program [arg1 arg2 ...]")
+        parser = OptionParser(
+            usage="%prog [options] -- program [arg1 arg2 ...]")
         self.createCommonOptions(parser)
         self.createLogOptions(parser)
         self.options, self.program = parser.parse_args()
@@ -255,8 +263,8 @@ class Gdb(Application):
 
     def parseBytes(self, text):
         # FIXME: Validate input
-#        if not BYTES_REGEX.match(text):
-#            raise ValueError('Follow text must be enclosed in quotes!')
+        #        if not BYTES_REGEX.match(text):
+        #            raise ValueError('Follow text must be enclosed in quotes!')
         if PY3:
             text = 'b' + text.lstrip()
         value = eval(text)
@@ -284,7 +292,7 @@ class Gdb(Application):
     def xray(self):
         for process, procmap, address, term in self._xray():
             pointers = " ".join(formatAddress(ptr_addr)
-                for ptr_addr in getPointers(process, address))
+                                for ptr_addr in getPointers(process, address))
             print("term[%s] pid[%i] %s %s pointers: %s" % (
                 repr(term), process.pid, procmap,
                 formatAddress(address),
@@ -304,6 +312,8 @@ class Gdb(Application):
             self.process.dumpRegs()
         elif command == "stack":
             self.process.dumpStack()
+        elif command == "gcore":
+            self.gcore(self.process)
         elif command == "backtrace":
             errmsg = self.backtrace()
         elif command == "where" or command.startswith("where "):
@@ -363,12 +373,12 @@ class Gdb(Application):
         except KeyError:
             pass
         try:
-            return SIGNALS["SIG"+command]
+            return SIGNALS["SIG" + command]
         except KeyError:
             pass
         try:
             return self.parseInteger(command)
-        except ValueError as err:
+        except ValueError:
             raise ValueError("Invalid signal number: %r" % command)
 
     def signal(self, command):
@@ -399,6 +409,26 @@ class Gdb(Application):
             error("Address is part of mapping: %s" % map)
         return None
 
+    def gcore(self, process):
+        import re
+        childPid = str(process).split('#')[-1][:-1]
+        maps_file = open("/proc/" + childPid + "/maps", 'r')
+        mem_file = open("/proc/" + childPid + "/mem", 'r', 0)
+        from sys import argv
+        dump = open("/vmdump/" + argv[1] + ".dump", "wb")
+        for line in maps_file.readlines():  # for each mapped region
+            m = re.match(r'([0-9A-Fa-f]+)-([0-9A-Fa-f]+) ([-r])', line)
+            if m.group(3) == 'r':  # if this is a readable region
+                if "/lib" not in line and "/usr" not in line:  # for eliminating of shared libs
+                    start = int(m.group(1), 16)
+                    end = int(m.group(2), 16)
+                    mem_file.seek(start)  # seek to region start
+                    chunk = mem_file.read(end - start)  # read region contents
+                    dump.write(chunk,)  # dump contents to standard output
+        maps_file.close()
+        mem_file.close()
+        dump.close()
+
     def hexdump(self, command):
         max_line = 20
         width = (terminalWidth() - len(formatAddress(1)) - 3) // 4
@@ -412,11 +442,11 @@ class Gdb(Application):
                 end_address = self.parseInteger(parts[1])
                 if end_address <= start_address:
                     raise ValueError('End address (%s) is smaller than start address(%s)!'
-                        % (formatAddress(end_address), formatAddress(start_address)))
+                                     % (formatAddress(end_address), formatAddress(start_address)))
             except ValueError as err:
                 return str(err)
             size = end_address - start_address
-            max_size = width*max_line
+            max_size = width * max_line
             if max_size < size:
                 limited = max_size
                 end_address = start_address + max_size
@@ -425,7 +455,7 @@ class Gdb(Application):
                 start_address = self.parseInteger(command)
             except ValueError as err:
                 return str(err)
-            end_address = start_address + 5*width
+            end_address = start_address + 5 * width
 
         read_error = None
         address = start_address
@@ -437,7 +467,7 @@ class Gdb(Application):
 
                 # Format bytes
                 hexa = formatHexa(memory)
-                hexa = hexa.ljust(width*3-1, ' ')
+                hexa = hexa.ljust(width * 3 - 1, ' ')
 
                 ascii = formatAscii(memory)
                 ascii = ascii.ljust(width, ' ')
@@ -505,7 +535,7 @@ class Gdb(Application):
                 return 'Register name (%s) have to start with "$"' % key
             key = key[1:]
         except ValueError as err:
-             return "Invalid command: %r" % command
+            return "Invalid command: %r" % command
         try:
             value = self.parseInteger(value)
         except ValueError as err:
@@ -532,7 +562,7 @@ class Gdb(Application):
         try:
             pid = self.parseInteger(text)
         except ValueError as err:
-             return str(err)
+            return str(err)
         process = self.debugger.addProcess(pid, False)
         self.switchProcess(process)
 
@@ -573,7 +603,7 @@ class Gdb(Application):
     def newProcess(self, event):
         error("New process: %s" % event.process)
 
-    # FIXME: This function doesn't work multiple multiple processes
+    # FIXME: This function doesn't work with multiple processes
     # especially when a parent waits for a child
     def syscallTrace(self):
         # Trace until syscall enter
@@ -602,7 +632,7 @@ class Gdb(Application):
         try:
             address = self.parseInteger(command)
         except ValueError as err:
-             return str(err)
+            return str(err)
         errmsg = self.step(False, address)
         if errmsg:
             return errmsg
@@ -622,7 +652,7 @@ class Gdb(Application):
         try:
             pid = self.parseInteger(command)
         except ValueError as err:
-             return str(err)
+            return str(err)
         try:
             process = self.debugger[pid]
             self.switchProcess(process)
@@ -705,7 +735,8 @@ class Gdb(Application):
         error('')
         error("Value can be an hexadecimal/decimal number or a register name ($reg)")
         error("You can use operators a+b, a-b, a*b, a/b, a<<b, a>>b, a**b, and parenthesis in expressions")
-        error('Use ";" to write multiple commands on the same line (eg. "step; print $eax")')
+        error(
+            'Use ";" to write multiple commands on the same line (e.g. "step; print $eax")')
 
     def processSignal(self, event):
         event.display()
@@ -854,6 +885,6 @@ class Gdb(Application):
         error("Quit gdb.")
         self.restoreTerminal()
 
+
 if __name__ == "__main__":
     Gdb().main()
-
