@@ -2,19 +2,20 @@
 from __future__ import print_function
 from ptrace import PtraceError
 from ptrace.debugger import (PtraceDebugger, Application,
-    ProcessExit, ProcessSignal, NewProcessEvent, ProcessExecution)
+                             ProcessExit, ProcessSignal, NewProcessEvent, ProcessExecution)
 from ptrace.syscall import (SYSCALL_NAMES, SYSCALL_PROTOTYPES,
-    FILENAME_ARGUMENTS, SOCKET_SYSCALL_NAMES)
+                            FILENAME_ARGUMENTS, SOCKET_SYSCALL_NAMES)
 from ptrace.func_call import FunctionCallOptions
 from sys import stderr, exit
 from optparse import OptionParser
 from logging import getLogger, error
-from ptrace.syscall.socketcall_constants import SOCKETCALL
 from ptrace.error import PTRACE_ERRORS, writeError
 from ptrace.ctypes_tools import formatAddress
 import re
 
+
 class SyscallTracer(Application):
+
     def __init__(self):
         Application.__init__(self)
 
@@ -34,43 +35,44 @@ class SyscallTracer(Application):
         self._setupLog(fd)
 
     def parseOptions(self):
-        parser = OptionParser(usage="%prog [options] -- program [arg1 arg2 ...]")
+        parser = OptionParser(
+            usage="%prog [options] -- program [arg1 arg2 ...]")
         self.createCommonOptions(parser)
         parser.add_option("--enter", help="Show system call enter and exit",
-            action="store_true", default=False)
+                          action="store_true", default=False)
         parser.add_option("--profiler", help="Use profiler",
-            action="store_true", default=False)
+                          action="store_true", default=False)
         parser.add_option("--type", help="Display arguments type and result type (default: no)",
-            action="store_true", default=False)
+                          action="store_true", default=False)
         parser.add_option("--name", help="Display argument name (default: no)",
-            action="store_true", default=False)
+                          action="store_true", default=False)
         parser.add_option("--string-length", "-s", help="String max length (default: 300)",
-            type="int", default=300)
+                          type="int", default=300)
         parser.add_option("--array-count", help="Maximum number of array items (default: 20)",
-            type="int", default=20)
+                          type="int", default=20)
         parser.add_option("--raw-socketcall", help="Raw socketcall form",
-            action="store_true", default=False)
+                          action="store_true", default=False)
         parser.add_option("--output", "-o", help="Write output to specified log file",
-            type="str")
-        parser.add_option("--ignore-regex", help="Regex used to filter syscall names (eg. --ignore='^(gettimeofday|futex|f?stat)')",
-            type="str")
-        parser.add_option("--address", help="Display structure addressl",
-            action="store_true", default=False)
+                          type="str")
+        parser.add_option("--ignore-regex", help="Regex used to filter syscall names (e.g. --ignore='^(gettimeofday|futex|f?stat)')",
+                          type="str")
+        parser.add_option("--address", help="Display structure address",
+                          action="store_true", default=False)
         parser.add_option("--syscalls", '-e', help="Comma separated list of shown system calls (other will be skipped)",
-            type="str", default=None)
+                          type="str", default=None)
         parser.add_option("--socket", help="Show only socket functions",
-            action="store_true", default=False)
+                          action="store_true", default=False)
         parser.add_option("--filename", help="Show only syscall using filename",
-            action="store_true", default=False)
+                          action="store_true", default=False)
         parser.add_option("--show-pid",
-            help="Prefix line with process identifier",
-            action="store_true", default=False)
+                          help="Prefix line with process identifier",
+                          action="store_true", default=False)
         parser.add_option("--list-syscalls",
-            help="Display system calls and exit",
-            action="store_true", default=False)
+                          help="Display system calls and exit",
+                          action="store_true", default=False)
         parser.add_option("-i", "--show-ip",
-            help="print instruction pointer at time of syscall",
-            action="store_true", default=False)
+                          help="print instruction pointer at time of syscall",
+                          action="store_true", default=False)
 
         self.createLogOptions(parser)
 
@@ -99,11 +101,12 @@ class SyscallTracer(Application):
                 valid_names = list(SYSCALL_NAMES.values())
                 for name in only:
                     if name not in valid_names:
-                        print("ERROR: unknow syscall %r" % name, file=stderr)
+                        print("ERROR: unknown syscall %r" % name, file=stderr)
                         ok = False
                 if not ok:
                     print(file=stderr)
-                    print("Use --list-syscalls options to get system calls list", file=stderr)
+                    print(
+                        "Use --list-syscalls options to get system calls list", file=stderr)
                     exit(1)
                 # remove duplicates
                 only.add(item)
@@ -139,7 +142,6 @@ class SyscallTracer(Application):
         return False
 
     def displaySyscall(self, syscall):
-        name = syscall.name
         text = syscall.format()
         if syscall.result is not None:
             text = "%-40s = %s" % (text, syscall.result_text)
@@ -164,13 +166,12 @@ class SyscallTracer(Application):
             # Wait until next syscall enter
             try:
                 event = self.debugger.waitSyscall()
-                process = event.process
             except ProcessExit as event:
                 self.processExited(event)
                 continue
             except ProcessSignal as event:
                 event.display()
-                process.syscall(event.signum)
+                event.process.syscall(event.signum)
                 continue
             except NewProcessEvent as event:
                 self.newProcess(event)
@@ -180,7 +181,7 @@ class SyscallTracer(Application):
                 continue
 
             # Process syscall enter or exit
-            self.syscall(process)
+            self.syscall(event.process)
 
     def syscall(self, process):
         state = process.syscall_state
@@ -195,8 +196,8 @@ class SyscallTracer(Application):
         # Display syscall which has not exited
         state = event.process.syscall_state
         if (state.next_event == "exit") \
-        and (not self.options.enter) \
-        and state.syscall:
+                and (not self.options.enter) \
+                and state.syscall:
             self.displaySyscall(state.syscall)
 
         # Display exit message
@@ -265,6 +266,6 @@ class SyscallTracer(Application):
             program[0], program, pid))
         return pid
 
+
 if __name__ == "__main__":
     SyscallTracer().main()
-
